@@ -37,3 +37,24 @@ SELECT * FROM u WHERE u = meter(400);
 SELECT * FROM u WHERE u = '300' * kilogram();
 EXPLAIN (COSTS OFF) SELECT * FROM u WHERE u = meter(400);
 EXPLAIN (COSTS OFF) SELECT * FROM u WHERE u = '300' * kilogram();
+
+-- test strict operators
+SELECT '1 m'::unit << '1 m'::unit;
+SELECT '1 m'::unit << '1 A'::unit;
+SELECT '1 m'::unit <<= '1 m'::unit;
+SELECT '1 m'::unit <<= '1 A'::unit;
+SELECT '1 m'::unit == '1 m'::unit;
+SELECT '1 m'::unit == '1 A'::unit;
+SELECT '1 m'::unit <<>> '1 m'::unit;
+SELECT '1 m'::unit <<>> '1 A'::unit;
+SELECT '1 m'::unit >>= '1 m'::unit;
+SELECT '1 m'::unit >>= '1 A'::unit;
+SELECT '1 m'::unit >> '1 m'::unit;
+SELECT '1 m'::unit >> '1 A'::unit;
+
+-- test range type
+SELECT 'empty'::unitrange;
+SELECT '(1 m, 2 m)'::unitrange;
+SELECT '(1 m, 2 A)'::unitrange;
+SELECT unit_diff('1 A', '2 A');
+SELECT unit_diff('1 A', '2 K');
